#! /bin/csh -x
#PBS -N relax
#PBS -A ocean-osse
#PBS -d .
#PBS -q batch
#PBS -o relax.out
#PBS -e relax.err
#PBS -l walltime=00:15:00
#PBS -l procs=1
#
set echo
set time = 1
C
setenv OS `uname`
switch ($OS)
case 'SunOS':
    breaksw
case 'Linux':
    breaksw
case 'OSF1':
    breaksw
case 'IRIX64':
    breaksw
case 'AIX':
    breaksw
case 'unicosmk':
    breaksw
default:
    echo 'Unknown Operating System: ' $OS
    exit (1)
endsw
C
C --- Convert z-level climatology to HYCOM layers.
C
switch ($OS)
case 'SunOS':
    if (-e /scr) then
      setenv pget ~wallcraf/bin/pget
      setenv pput ~wallcraf/bin/pput
    else
      setenv pget cp
      setenv pput cp
    endif
    breaksw
case 'XXX':
    setenv pget ~wallcraf/bin/pget
    setenv pput ~wallcraf/bin/pput
    breaksw
default:
    setenv pget cp
    setenv pput cp
endsw
C
C --- E is experiment number, from EXPT.src
C --- R is region identifier, from EXPT.src
C --- T is topog. identifier, from EXPT.src
C
C --- P is primary path,
C --- S is scratch directory,
C --- DW is permanent WORK directory
C --- DA is permanent ARCHIVE directory
C --- SIG is sig2 or sig2
C
source EXPT.src
C
setenv P hycom/${R}/relax/${E}
setenv SIG sig2
C
switch ($OS)
case 'AIX':
    setenv S /scr/${user}/hycom/scratch
    setenv D /scr/${user}/$P
breaksw
case 'SunOS':
    if (-e /scr) then
#                  NAVO MSRC
      setenv S /scr/${user}/$P
      setenv D            ~/$P
    else if (-e /net/hermes/scrb) then
#                  NRLSSC
      setenv S /net/hermes/scrb/${user}/$P
      setenv D                        ~/$P
    else
#                  Single Disk
      setenv S ~/$P/SCRATCH
      setenv D ~/$P
    endif
    breaksw
case 'Linux':
    if (-e /external/fast) then
#                  NRLSSC
      setenv S /external/fast/${user}/$P
      setenv D                      ~/$P
    else
#                  Single Disk
      setenv DW ~$USER/$P
      setenv DA ~/l3/$P
      setenv S ${DA}/SCRATCH
    endif
    breaksw
default:
#                  Single Disk
    setenv S $P/SCRATCH
    setenv D $P
endsw
C
mkdir -p $S
cd       $S
C
touch   relax_${SIG}_new blkdat.input fort.51 fort.51A
/bin/rm relax_${SIG}_new blkdat.input fort.51 fort.51A
C
C --- 12 months
C
foreach MM ( 01 02 03 04 05 06 07 08 09 10 11 12 )
C
C --- Input.
C
touch      fort.71 fort.71A fort.72 fort.72A
/bin/rm -f fort.71 fort.71A fort.72 fort.72A
${pget} ${DA}/../flat/dens_${SIG}_m${MM}.b fort.71  &
${pget} ${DA}/../flat/dens_${SIG}_m${MM}.a fort.71A &
${pget} ${DA}/../flat/temp_${SIG}_m${MM}.b fort.72  &
${pget} ${DA}/../flat/temp_${SIG}_m${MM}.a fort.72A &
wait
C
touch fort.51 fort.51A
if (-z fort.51) then
  ${pget} ${DA}/../../topo/depth_${R}_${T}.b fort.51  &
  wait
endif
if (-z fort.51A) then
  ${pget} ${DA}/../../topo/depth_${R}_${T}.a fort.51A &
  wait
endif
C
touch regional.grid.a regional.grid.b
if (-z regional.grid.b) then
  ${pget} ${DW}/../../topo/regional.grid.b regional.grid.b &
  wait
endif
if (-z regional.grid.a) then
  ${pget} ${DW}/../../topo/regional.grid.a regional.grid.a &
  wait
endif
C
touch blkdat.input
if (-z blkdat.input) then
  ${pget} ${DW}/blkdat.input blkdat.input &
  wait
endif
C
touch relax_${SIG}_new
if (-z relax_${SIG}_new) then
  ${pget} ${DW}/../../../ALL_old/relax/src/relax_${SIG}_new . &
  wait
endif
C
chmod a+rx relax_${SIG}_new
C
sed -e "s/^[ 	0-9]*'month ' =/  ${MM}	  'month ' =/" blkdat.input >! fort.99
C
switch ($OS)
case 'SunOS':
    /bin/rm -f core relax_${SIG}_new.trace
    touch core
    breaksw
default:
    /bin/rm -f core
    touch core
endsw
C
setenv FOR010A fort.10A
setenv FOR011A fort.11A
setenv FOR012A fort.12A
setenv FOR021A fort.21A
setenv FOR051A fort.51A
setenv FOR071A fort.71A
setenv FOR072A fort.72A
/bin/rm -f fort.10  fort.11  fort.12  fort.21
/bin/rm -f fort.10A fort.11A fort.12A fort.21A
C
./relax_${SIG}_new
switch ($OS)
case 'SunOS':
    if (-e relax_${SIG}_new.trace) then
      cat relax_${SIG}_new.trace
    endif
    breaksw
default:
endsw
C
C --- Output.
C
mv fort.10  relax_tem_m${MM}.b
mv fort.10A relax_tem_m${MM}.a
mv fort.11  relax_sal_m${MM}.b
mv fort.11A relax_sal_m${MM}.a
mv fort.12  relax_int_m${MM}.b
mv fort.12A relax_int_m${MM}.a
C
#setenv DAYM `echo ${MM} | awk '{printf("0000_%3.3d_00\n",30*($1-1)+16)}'`
setenv DAYM `echo ${MM} | awk '{printf("0000_%3.3d_00\n",30.5*($1-1)+16)}'`
#setenv DAYM `echo ${MM} | awk '{printf("0000_%3.3d_00\n",30.5*($1-1)+1)}'`
${pput} fort.21  relax.${DAYM}.b
${pput} fort.21A relax.${DAYM}.a
/bin/rm fort.21 fort.21A
C
C --- end of month foreach loop
C
/bin/rm fort.7[12]
end
#
# --- Merge monthly climatologies into one file.
#
cp relax_int_m01.b relax_int.b
cp relax_sal_m01.b relax_sal.b
cp relax_tem_m01.b relax_tem.b
#
foreach MM ( 02 03 04 05 06 07 08 09 10 11 12 )
  tail -n +6 relax_int_m${MM}.b >> relax_int.b
  tail -n +6 relax_sal_m${MM}.b >> relax_sal.b
  tail -n +6 relax_tem_m${MM}.b >> relax_tem.b
end
#
cp relax_int_m01.a relax_int.a
cp relax_sal_m01.a relax_sal.a
cp relax_tem_m01.a relax_tem.a
#
foreach MM ( 02 03 04 05 06 07 08 09 10 11 12 )
  cat relax_int_m${MM}.a >> relax_int.a
  cat relax_sal_m${MM}.a >> relax_sal.a
  cat relax_tem_m${MM}.a >> relax_tem.a
end
${pput} relax_int.b ${DA}/relax_int.b
${pput} relax_int.a ${DA}/relax_int.a
${pput} relax_sal.b ${DA}/relax_sal.b
${pput} relax_sal.a ${DA}/relax_sal.a
${pput} relax_tem.b ${DA}/relax_tem.b
${pput} relax_tem.a ${DA}/relax_tem.a
${pput} *0000* ${DA}/.
#
# --- delete the monthly files
#
/bin/rm relax_int_m??.[ab]
/bin/rm relax_sal_m??.[ab]
/bin/rm relax_tem_m??.[ab]
#C
#C --- Delete all scratch directory files.
#C
#/bin/rm -f *
